@@ -1,15 +1,16 @@
 
 from ..userAgentManager import *
+
 from ..cipherManager import *
 from ..sslManager import *
 from ..tlsAdapter import *
+
 from ..networkManager import *
 from ..seleneumManager import *
 from ..urlManager import *
-logging.basicConfig(level=logging.INFO)
-logging.basicConfig(level=logging.INFO)
+##logging.basicConfig(level=logging.INFO)
+##logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
-
 # --- Cookie normalizer ---
 def normalize_cookies(cookies):
     """
@@ -94,6 +95,8 @@ class requestManager:
         - The SafeRequest class is designed for making HTTP requests with error handling and retries.
         - It provides methods for authentication, response handling, and error management.
     """
+def ensure_bytes(x):
+    return x if isinstance(x, bytes) else x.encode("utf-8")
 class requestManager:
     def __init__(self, url=None, source_code=None, url_mgr=None, network_manager=None,
                  ua_mgr=None, ssl_manager=None, ssl_options=None, tls_adapter=None,
@@ -129,7 +132,7 @@ class requestManager:
             certification=certification,
             ssl_options=ssl_options
         )
-
+        
         # Session
         self.session = session or requests.Session()
         self.session.proxies = self.network_manager.proxies
@@ -155,7 +158,7 @@ class requestManager:
         self.last_request_time = last_request_time
         self.max_retries = max_retries or 3
         self.request_wait_limit = request_wait_limit or 1.5
-
+        
         # Response placeholders ...
         self._response = None
         self.status_code = None
@@ -166,14 +169,13 @@ class requestManager:
         self.extracted_urls = []
         self.php_blocks = []
         self._response_data = None
-
+        
         if source_code is not None:
             self._response = source_code
             self.process_response_data()
         else:
             self.re_initialize()
 
-
     def update_url_mgr(self, url_mgr):
         self.url_mgr = url_mgr
         self.re_initialize()
@@ -256,34 +258,42 @@ class requestManager:
 
 
     def process_response_data(self):
-        """Processes the fetched response data."""
-        if not self.response:
-            return  # No data to process
-        if isinstance(self.response, (str, bytes)):
-            if isinstance(self.response, str):
-                self.source_code = self.response
-                self.source_code_bytes = self.response.encode('utf-8')  # Assume UTF-8
-            else:
-                self.source_code_bytes = self.response
-                try:
-                    self.source_code = self.response.decode('utf-8')
-                except UnicodeDecodeError:
-                    self.source_code = self.response.decode('latin-1')  # Fallback
-            # Check if it's JSON
-            try:
-                data = json.loads(self.source_code)
-                self.source_code_json = data.get("response", data)
-            except json.JSONDecodeError:
-                pass
+        if self.response is None:
+            return
+
+        self.source_code = None
+        self.source_code_json = None
+
+        # -------------------------------
+        # Normalize WITHOUT charset probing
+        # -------------------------------
+        if isinstance(self.response, bytes):
+            raw = self.response
+
+        elif isinstance(self.response, str):
+            self.source_code = self.response
+            raw = None
+
+        elif hasattr(self.response, "content"):  # requests.Response
+            raw = self.response.content
+
         else:
-            self.source_code = self.response.text
-            self.source_code_bytes = self.response.content
-            if self.response.headers.get('content-type', '').startswith('application/json'):
-                try:
-                    data = json.loads(self.source_code)
-                    self.source_code_json = data.get("response", data)
-                except json.JSONDecodeError:
-                    pass
+            raise TypeError(f"Unsupported response type: {type(self.response)}")
+
+        # Decode ONLY if needed
+        if self.source_code is None and raw is not None:
+            try:
+                self.source_code = raw.decode("utf-8")
+            except UnicodeDecodeError:
+                self.source_code = raw.decode("latin-1")
+
+        # JSON detection
+        try:
+            data = json.loads(self.source_code)
+            self.source_code_json = data.get("response", data)
+        except json.JSONDecodeError:
+            pass
+
         self.extract_urls()
         self.extract_php_blocks()
         self.get_react_source_code()
@@ -303,30 +313,42 @@ class requestManager:
         self.php_blocks = re.findall(php_pattern, self.source_code, re.DOTALL)
 
     def get_react_source_code(self) -> list:
-        """
-        Extracts JavaScript and JSX source code from <script> tags if HTML-like.
-        If not HTML and looks like JS/React code, appends the whole source_code.
-        """
         if not self.source_code:
             return []
-        # Check if likely JS code (e.g., contains 'import', 'function', 'React')
-        is_js_like = any(keyword in self.source_code.lower() for keyword in ['import ', 'function ', 'react', 'export ', 'const ', 'let ', 'var '])
-        # Check if HTML-like
-        is_html_like = self.source_code.strip().startswith('<') or '<html' in self.source_code.lower() or '<!doctype' in self.source_code.lower()
+
+        is_js_like = any(
+            kw in self.source_code.lower()
+            for kw in ['import ', 'function ', 'react', 'export ', 'const ', 'let ', 'var ']
+        )
+
+        is_html_like = (
+            self.source_code.lstrip().startswith('<')
+            or '<html' in self.source_code.lower()
+            or '<!doctype' in self.source_code.lower()
+        )
+
         if not is_html_like and is_js_like:
             self.react_source_code.append(self.source_code)
             return self.react_source_code
-        content = self.source_code_bytes or self.source_code.encode('utf-8')
-        soup = BeautifulSoup(content, "html.parser")
-        script_tags = soup.find_all('script', type=lambda t: t and ('javascript' in t.lower() or 'jsx' in t.lower()))
+
+        # ✅ PASS STRING — NOT BYTES
+        soup = BeautifulSoup(self.source_code, "html.parser")
+
+        script_tags = soup.find_all(
+            'script',
+            type=lambda t: t and ('javascript' in t.lower() or 'jsx' in t.lower())
+        )
+
         for script_tag in script_tags:
             if script_tag.string:
                 self.react_source_code.append(script_tag.string)
-        # If no scripts found but JS-like, append whole
+
         if not script_tags and is_js_like:
             self.react_source_code.append(self.source_code)
+
         return self.react_source_code
 
+
     def initialize_session(self):
         # Already done in __init__; keep for API compatibility
         return self.session
