@@ -2,7 +2,7 @@ from ..urlManager import *
 from ..requestManager import *
 from bs4 import BeautifulSoup
 import re, json
-
+from bs4 import BeautifulSoup, Tag
 class soupManager:
     """
     SoupManager is a class for managing and parsing HTML source code using BeautifulSoup.
@@ -146,10 +146,7 @@ class soupManager:
     def update_parse_type(self,parse_type):
         self.parse_type=parse_type
         self.re_initialize()
-
-
-
-
+        
     def get_all_website_links(self, tag="a", attr="href") -> list:
         """Return all same-domain URLs found in anchors (or given tag/attr)."""
         urls = []
@@ -202,10 +199,128 @@ class soupManager:
         soup = self.soup if soup is None else soup
         return soup.find_all(element)
 
-    def get_class(self, class_name, soup=None):
-        soup = self.soup if soup is None else soup
-        # Return the "class" attribute (list) of a Tag if present
-        return soup.get(class_name) if hasattr(soup, "get") else None
+
+    def findit(self, criteria, *, soup=None):
+        """
+        The One True findit — stops at first match, exactly as you commanded.
+
+        "span" → returns the moment it finds:
+            • tag name == span
+            OR
+            • any attribute name contains "span"
+            OR
+            • any attribute value contains "span"
+            OR
+            • text content contains "span"
+
+        As soon as one condition wins → all tags matching that condition are returned.
+        No further conditions are checked for that term.
+        """
+        soup = soup or self.soup
+        if not soup:
+            return []
+
+        results = []
+        seen = set()  # dedupe by identity
+
+        for term in make_list(criteria):
+            term_str = str(term).lower().strip()
+            if not term_str:
+                continue
+
+            # Case 1: Structured dict — precise, respectful, always checked fully
+            if isinstance(term, dict):
+                for tag_name, condition in term.items():
+                    tag_name = tag_name.lower()
+                    candidates = soup.find_all(tag_name) if tag_name else soup.find_all(True)
+
+                    for tag in candidates:
+                        if not isinstance(tag, Tag) or id(tag) in seen:
+                            continue
+
+                        if condition is None:
+                            # {"span": None} → just the tag
+                            results.append(tag)
+                            seen.add(id(tag))
+                            continue
+
+                        if isinstance(condition, dict):
+                            match = True
+                            for attr, expected in condition.items():
+                                attr = attr.lower()
+                                val = tag.get(attr)
+
+                                if expected is None:
+                                    if val is None:
+                                        match = False
+                                        break
+                                elif callable(expected):
+                                    if not expected(val):
+                                        match = False
+                                        break
+                                else:
+                                    expected_vals = make_list(expected)
+                                    actual_vals = make_list(val) if val is not None else []
+                                    if attr == "class":
+                                        if not any(e in a for e in expected_vals for a in actual_vals):
+                                            match = False
+                                            break
+                                    elif not any(str(e) in str(a) for e in expected_vals for a in actual_vals):
+                                        match = False
+                                        break
+                            if match:
+                                results.append(tag)
+                                seen.add(id(tag))
+                continue  # dict terms are precise — don't fall through to loose search
+
+            # Case 2: Loose string search — "span"
+            # We check in priority order — stop at first winning condition
+            found = False
+
+            # 1. Tag name contains term → highest priority
+            for tag in soup.find_all(lambda t: term_str in t.name.lower()):
+                if id(tag) not in seen:
+                    results.append(tag)
+                    seen.add(id(tag))
+            if results and len(results) > len(seen) - 100:  # heuristic: many matches → likely done
+                found = True
+
+            # 2. Attribute NAME contains term
+            if not found:
+                for tag in soup.find_all(True):
+                    if id(tag) in seen:
+                        continue
+                    if any(term_str in attr_name.lower() for attr_name in tag.attrs):
+                        results.append(tag)
+                        seen.add(id(tag))
+                        found = True
+
+            # 3. Attribute VALUE contains term
+            if not found:
+                for tag in soup.find_all(True):
+                    if id(tag) in seen:
+                        continue
+                    if any(term_str in str(val).lower() for val in tag.attrs.values() for val in make_list(val)):
+                        results.append(tag)
+                        seen.add(id(tag))
+                        found = True
+
+            # 4. Text content contains term — last resort
+            if not found:
+                for tag in soup.find_all(string=lambda s: s and term_str in s.lower()):
+                    parent = tag.parent
+                    if isinstance(parent, Tag) and id(parent) not in seen:
+                        results.append(parent)
+                        seen.add(id(parent))
+
+        # Return in original document order
+        ordered = []
+        for tag in soup.descendants:
+            if isinstance(tag, Tag) and id(tag) in seen:
+                ordered.append(tag)
+                if len(ordered) == len(seen):
+                    break
+        return ordered
     @staticmethod
     def has_attributes(tag, *attrs):
         return any(tag.has_attr(attr) for attr in attrs)
@@ -323,7 +438,7 @@ class soupManager:
         attribute_names_list = list(attribute_names)
         return {"tags":tag_names_list,"attributes":attribute_names_list}
 
-    def get_all_attribute_values(self, tags_list=None):
+    def get_all_attribute_values(self, tags_lists=None):
         """
         Collects all attribute values for each specified tag or all tags if none are specified.
         
@@ -335,19 +450,20 @@ class soupManager:
         - attribute_values: Dictionary where each key is an attribute and the value is a list of unique values for that attribute.
         """
         attribute_values = {}
-        tags_list = tags_list or self.get_all_tags_and_attribute_names()
+        tags_lists = tags_lists or self.get_all_tags_and_attribute_names()
         # Get all tags matching tags_list criteria
-        for tag_name in tags_list:
-            for tag in self.soup.find_all(tag_name):
-                for attr, value in tag.attrs.items():
-                    if attr not in attribute_values:
-                        attribute_values[attr] = set()
-                    
-                    # Add attribute values
-                    if isinstance(value, list):
-                        attribute_values[attr].update(value)
-                    else:
-                        attribute_values[attr].add(value)
+        for key,tags_list in tags_lists.items():
+            for tag_name in tags_list:
+                for tag in self.soup.find_all(tag_name):
+                    for attr, value in tag.attrs.items():
+                        if attr not in attribute_values:
+                            attribute_values[attr] = set()
+                        
+                        # Add attribute values
+                        if isinstance(value, list):
+                            attribute_values[attr].update(value)
+                        else:
+                            attribute_values[attr].add(value)
         
         # Convert each set to a list for consistency
         for attr, values in attribute_values.items():
@@ -375,6 +491,9 @@ class soupManager:
     def url(self, new_url):
         self._url = new_url
 
+
+
+
 class SoupManagerSingleton():
     _instance = None
     @staticmethod
