@@ -1,3 +1,13 @@
+import os, sys, base64
+from pathlib import Path
+from PyQt6 import QtWidgets, QtGui, QtCore
+from PyQt6.QtGui import QPixmap, QFileSystemModel, QDesktopServices
+from PyQt6.QtCore import QUrl, QSize, QRect
+
+from abstract_apis import postRequest
+
+
+
 import logging
 import requests
 from .functions.url_utils import parse_url, dictquery, reconstructUrlParse, reconstructNetLoc
@@ -33,9 +43,10 @@ class urlManager:
     def update_url(self, url):
         """Update the URL and refresh related attributes."""
         self._url = url
+        self.parsed = parse_url(self._url)
         if url is None:
-            self.clean_urls = []
-            self.url = None
+            self.clean_urls = self.parsed.get('valid_variants')
+            self.url = self.parsed.get('full_url')
             self.protocol = None
             self.domain = None
             self.path = ""
@@ -44,20 +55,21 @@ class urlManager:
             return
 
         # Parse + normalize
-        self.parsed = parse_url(url)
-        self.clean_urls = self._generate_variants(self.parsed)
-        self.url = self.get_correct_url() or reconstructUrlFromUrlParse(parsed=self.parsed)
+        self.parsed = parse_url(self._url)
+        self.valid_variants = self.parsed.get('valid_variants')
+        self.path = self.parsed.get('path')
+        self.clean_urls = [f"{variant}/{self.path}" for variant in self.valid_variants if variant]
+        self.url = self.parsed.get('full_url')
         self.protocol = self.parsed.get("scheme")
-        self.domain = reconstructNetLoc(self.parsed.get("netloc"))
-        self.path = self.parsed.get("path")
+        self.domain = self.parsed.get('full_domain')
         self.query = self.parsed.get("query")
         self.all_urls = self.clean_urls
 
     def _generate_variants(self, parsed) -> list:
         """Generate candidate URLs using ALL_URL_KEYS (scheme, www, extensions)."""
-        netloc_data = parsed.get("netloc", {})
-        base_domain = netloc_data.get("domain", "")
-        ext = netloc_data.get("extention", "")
+        netloc_data = parsed.get("netloc")
+        base_domain = parsed.get("domain")
+        ext = parsed.get("ext")
         variants = []
 
         for scheme in ALL_URL_KEYS["scheme"]:
